@@ -68,7 +68,7 @@ class WeChat:
                 access_token=self.access_token)
 
             m = MultipartEncoder(
-                fields={filename: ('file', open(filepath + filename, 'rb'), 'text/plain')},
+                fields={filename: (filename, open(filepath + filename, 'rb'), 'text/plain')},
             )
             response = requests.post(url=post_file_url, data=m, headers={'Content-Type': m.content_type})
             if response.status_code == 200:
